{% extends "admin/change_list.html" %}
{% load i18n %}

{% block object-tools-items %}
  <li><a href="import/" class="import_link">{% trans "Import" %}</a></li>
  <li><a href="export/{{ cl.get_query_string }}" class="export_link">{% trans "Export" %}</a></li>
  {{ block.super }}
{% endblock %}